# SaverSwitcher (c) 2007 by Peter Watkins (peterw@tux.org) 
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License,
# version 2, which should be included with this software.

# # instantiate a Logging object
# my $log = Plugins::SaverSwitcher::Logging::new("MyPluginName");
#
# # indicate what sort of messages to log
# $log->setTypes( qw(menu prefs timers) );
# # or
# $log->setTypes( 'menu', 'prefs', 'timers' );
#
# # indicate what level to log (higher number == more messages)
# $log->setLevel(50);
#
#
# # log a message if $::d_plugins set *or* if logging 'all' types
# $log->msg("some message text");
#
# # log a message only if logging 'all' or 'web' types and at levels up to 25
# $log->msg('web', 25, "some message text");
#
# # log a message if $::d_plugins set *or* if logging *any* specific types
# $log->msg('any', 1, "some message text");

package Plugins::SaverSwitcher::Logging;

use strict;
# at least Perl 5
use 5;
use vars qw($VERSION @ISA @EXPORT);
require Exporter;
@ISA = qw(Exporter);
@EXPORT = qw();
$VERSION = '0.01';

my %logTypeNames = (
	# special type names:
	'all'	=>	255,
	'any'	=>	0,
	'none'	=>	256,
	# normal type names:
	'menu'	=>	1,
	'web'	=>	2,
	'buttons' =>	4,
	'timers' =>	8,
	'prefs' =>	16,
	'funcs' =>	32,
	'misc' =>	64,
);

sub typeCode {
	my $name = shift;
	my $code = $logTypeNames{lc($name)};
	if (! defined($code) ) {
		# default to something 
		Slim::Utils::Misc::msg("no code found for type \"$name\"\n");
		$code = $logTypeNames{'none'};
	}
	return (0 + $code);
}

sub new($) {
	my $self = {};
	$self->{pluginName} = shift;
	$self->{logTypes} = &typeCode('none');
	$self->{logLevel} = 0;
	bless $self;
	return $self;
}

sub msg {
	my $self = shift;
	my $message = pop @_;
	if (! defined($message) ) { return; }
	my ($typeName,$level) = @_;
	my $report = 0;
	if ( defined($typeName) && defined($level) ) {
		my $type = &typeCode($typeName);
		if ( $::d_plugins || ($level <= $self->{logLevel}) ) {
			if ( ($type & $self->{logTypes}) == $type ) {
				$report = 1;
			}
		}
	} else {
		if ( ($self->{logTypes} == &typeCode('all')) &&
		     ($self->{logLevel} > 0) ) { $report = 1; }
		if ( $::d_plugins ) { $report = 1; }
	}
	if ( $report == 1 ) {
		$message =~ s/[\r\n]*$//;
		Slim::Utils::Misc::msg($self->{pluginName}.": ${message}\n");
	}
}

sub setTypes {
	my $self = shift;
	my @types = @_;
	my $val = 0;
	foreach my $t ( @types ) {
		my $code = &typeCode($t);
		$val = $val ^ $code;
	}
	# make sure the 2^9 bit ('none') isn't set
	$val = $val % &typeCode('none');
	$self->{logTypes} = $val;
}

sub setLevel {
	my ($self, $level) = @_;
	$self->{logLevel} = $level;
}

1;

__END__

