# FuzzyTime (c) 2007 by Peter Watkins (peterw@tux.org) 
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License,
# version 2, which should be included with this software.

package Plugins::SaverSwitcher::Public;

#  ------------------------------------------------------------------------
# Other plugins can use this. 

# Pre-Usage Checks
#
# Register a pre-usage check function so that SaverSwitcher will only activate
# your screensaver if it is prepared to display something.
#
# This function will be passed a hash with the following keys:
#
# 		client		a Slim::Player::Client object for the player
# 		manual		1 if being considered because the user pressed a 1-9 button 
# 				to manually select your screensaver; 0 if the screensaver 
# 				is being considered for a normal cycle of "activated" savers,
# 				or if the user pressed the "0" button to pick the next active saver
# If the "manual" is 0. the following keys will also be passed:
# 		maxDuration	if being considered for a normal cycle of activated
# 				savers, this is the maximum duration that SaverSwitcher
# 				will allow for the screensaver, in seconds
# 		minDuration	if being considered for a normal cycle of activated
# 				savers, this is the minimum duration that SaverSwitcher
# 				will allow for the screensaver, in seconds
#
# This function should return a hash with the following key:
# 		allow		1 if the screensaver should be used, 0 if not
# If the "manual" is 0. the following key MAY be included in the return hash:
# 		duration	the number of seconds to display your screensaver if
# 				it is being used in a normal cycle of "activated" savers
# 				(SaverSwitcher will require at least minDuration seconds,
# 				 and no more than maxDuration seconds)
#
#	sub preUsageCheckFunction {
#		my $inputHash = shift;
#		my $client = $inputHash->{client};	# SaverSwitcher passes a client object
#		my $manual = $inputHash->{manual};	# 1 if user-requested, 0 if part of normal cycle of "active" savers
#		# in real life, you'd check some conditions
#		my %returnHash;
#		$returnHash{allow} = 1; # please do use this saver
#		#$returnHash{allow} = 0; # please DO NOT use this saver
#		return %returnHash;
#	}
#
# Then, define a subroutine to register with SaverSwitcher if SaverSwitcher
# is installed. Here's one you can copy and paste. It will return 1 if your
# pre-usage check function was registered sucessfully.
#
sub registerPreUsageCheckWithSaverSwitcher {
        my ($saverName, $coderef) = @_;
	my $ssVersion = $Plugins::SaverSwitcher::Plugin::apiVersion;
	if ( defined($ssVersion) && ($ssVersion >= 1.2) ) {
		return Plugins::SaverSwitcher::Public::registerPreUsageCheck($saverName, $coderef);
	}
	return 0;
}
#
# Finally, register your pre-usage check function with SaverSwitcher,
# typically in your initPlugin() routine.  $myScreensaverName MUST be the same 
# string token you passed as the first argument to 
# Slim::Buttons::Common::addSaver() when registering your screensaver 
# with SlimServer. A typical call would look like this:
#
#	my $registerResult = &registerPreUsageCheckWithSaverSwitcher($myScreensaverName,\&preUsageCheckFunction);
#
# To un-register your screensaver with SaverSwitcher, as you might do if  your plugin was sure 
# it should ALWAYS be used, pass undef instead of the coderef, e.g.
#
#	my $unregisterResult = &registerPreUsageCheckWithSaverSwitcher($myScreensaverName,undef);

#  ------------------------------------------------------------------------

# Other methods I am considering include
#
# 	getDefaultSaver($client,$screensaverType)
# 		to return the screensaver name (e.g. "SCREENSAVER.datetime")
# 		for a given client. This would allow other plugins to ascertain
# 		if a client was set to use SaverSwitcher for that mode, as 
# 		a simple client prefGet() will not return SaverSwitcher's name
# 		if the client is currently in that screensaver mode
#
# 	setDefaultSaver($client,$screensaverType,$saverName)
# 		to tell SaverSwitcher to change the player preference for that
# 		mode and *not* reset the player to SaverSwitcher. For instance,
# 		a plugin that sets the "Off" screensavers by time of day would want
# 		to do something like this
#
#			# functions
#			sub getSaver($$) {
#				my ($client,$saverType) = @_;
#				if ( defined($Plugins::SaverSwitcher::Plugin::apiVersion) ) {
# 					return Plugins::SaverSwitcher::Public::getDefaultSaver($client,$saverType);
# 				}
# 				return $client->prefGet($saverType);
# 			}
#			sub setSaver($$$) {
#				my ($client,$saverType,$saver) = @_;
#				if ( defined($Plugins::SaverSwitcher::Plugin::apiVersion) ) {
# 					return Plugins::SaverSwitcher::Public::setDefaultSaver($client,$saverType,$saver);
# 				}
# 				return $client->prefSet($saverType,$saver);
# 			}
#
# 			# when setting the screensaver
# 			$normalSaver{$client->id()} = &getSaver($client,'offsaver');
# 			Plugins::SaverSwitcher::Public::setDefaultSaver($client,'offsaver',$mySaverName);
# 			
# 			# to revert the screensaver
#			&setSaver($client,'offsaver',$normalSaver{$client->id()});

# public implementations, don't change these

sub registerPreUsageCheck {
        my ($saverName, $coderef) = @_;
	return Plugins::SaverSwitcher::Plugin::registerPreUsageCheck($saverName, $coderef);
}

1;
